@@ -34,7 +34,7 @@ import skyview.survey.Image;
  *
  * @author tmcglynn
  */
-public class ThresholdMedianSmoother implements Processor {
+public class ThresholdMedianSmoother extends Processor {
     
     private boolean ratio;
     private boolean topOnly;
@@ -104,6 +104,10 @@ public class ThresholdMedianSmoother implements Processor {
     }
     
     
+    public boolean updatesOutput() {
+        return true;
+    }
+    
     /** Do the median smoothing -- possibly with thresholding.
      * 
      * @param inputs   Input images (not used)
