@@ -538,7 +538,7 @@ public class Clip extends Sampler {
 	
 	// Handle pixels that go over the cuts in the projection
 	// plane by treating each region separately.
-	if (straddleCheck) {
+	if (straddleCheck  && !straddle) {
 	    double[][] z = new double[2][x.length];
 	    try {
 		// Transform from pixels to the standard projection plane
@@ -557,6 +557,9 @@ public class Clip extends Sampler {
 		}
 	        if (inProj.straddle(z)) {
  		    double[][][] fields = inProj.straddleComponents(z);
+                    if (fields == null) {
+                        return;
+                    }
 		    for (int i=0; i<fields.length; i += 1) {
 			// Convert from the standard projection plane to pixels.
                         inImgScaler.transform(fields[i], fields[i]);
