@@ -61,7 +61,7 @@ import java.util.HashSet;
  *  ensure that there the IJProcessor is included as a postprocessor,
  *  so the user need not explicitly specify this.
  */
-public class IJProcessor implements skyview.process.Processor {
+public class IJProcessor extends skyview.process.Processor {
     
     private static ImageStack[] rgb = new ImageStack[3];
     private static int lastHeight, lastWidth;
@@ -92,6 +92,10 @@ public class IJProcessor implements skyview.process.Processor {
     
     private HashSet<Color> colorHash;
     
+    public boolean updatesOutput() {
+        return false;
+    }
+    
     static {
 	byte[] r = new byte[256];
 	for (int i=0; i<r.length; i += 1) {
