@@ -13,12 +13,16 @@ import nom.tam.fits.Header;
 /** Used with QueryFinder to print out whether
  *  there is any coverage in the region of the image.
  */
-public class InfoPrint implements Processor {
+public class InfoPrint extends Processor {
  
     public String getName() {
 	return "InfoPrint";
     }
     
+    public boolean updatesOutput() {
+        return false;
+    }
+    
     /** Get a description of this component */
     public String getDescription() {
 	return "Indicate if an image has coverage in the survey.";
