@@ -9,7 +9,7 @@ import skyview.Component;
 import skyview.geometry.Sampler;
 import skyview.geometry.DepthSampler;
 
-public interface Processor extends Component {
+public abstract class Processor implements Component {
     
     /** Perform the processing task associated with this object.
      *  
@@ -27,4 +27,7 @@ public interface Processor extends Component {
     /** Update the FITS header to indicate what processing was done.
      */
     public abstract void updateHeader(nom.tam.fits.Header header);
+    
+    /** Does this processor actually modify the output array? */
+    public abstract boolean updatesOutput();
 }
