@@ -16,7 +16,11 @@ import java.util.regex.Pattern;
 import java.util.regex.Matcher;
 
 /** This class writes the HTML output for SkyView web services */
-public class HTMLWriter implements Processor {
+public class HTMLWriter extends Processor {
+     
+    public boolean updatesOutput() {
+        return false;
+    }
     
     /** Process the image.  This should happen late.
      * 
@@ -26,6 +30,7 @@ public class HTMLWriter implements Processor {
      * @param samp    The sampler used to create the output
      * @param dpSamp  For 3-d images the sampler in the energy axis.
      */
+    
     public void process(Image[] inputs, Image output, int[] sources,
 			Sampler samp, DepthSampler dpSamp) {
 	if (output == null) {
