@@ -12,6 +12,10 @@ public class SurveyException extends Exception {
     public SurveyException(String cause) {
 	super(cause);
     }
+    
+    public SurveyException(String cause, Exception prior) {
+        super(cause, prior);
+    }
 }
     
     
