@@ -461,7 +461,9 @@ public class XMLSurveyFinder implements SurveyFinder {
 		for (String cName: names) {
 		    cName = cName.trim().toLowerCase();
                     if (hash.containsKey(cName)) {
-                        System.err.println("Ambiguous survey short name:"+cName);
+                        System.err.println("Ambiguous survey short name:"+cName+"\n"+
+                                           "  Defined in both:"+hash.get(cName).name+"\n"+
+                                           "                  "+fileName);
                     }
                     SurveyLink lnk = new SurveyLink();
                     lnk.name = fileName;
